fgread-py
=========

General Documentation
---------------------

If you want to learn how to use the readers see our `FASTGenomics documentation <https://beta.fastgenomics.org/docs>`_.

Details on our API
------------------

For details on the available functions see the :doc:`API <api>` section

.. toctree::
   :maxdepth: 2

   api
